<div align="center">
  <img src="https://raw.githubusercontent.com/DirksCGM/DBtoS3/master/static/logo.png"><br>
</div>

Replication & Full Load Application for multiple databases to s3

## How to use

Please make use of the [Wiki](https://github.com/DirksCGM/DBtoS3/wiki) which will be updated continuously with information.

## Current Support
* [PostgreSQL to S3](https://github.com/DirksCGM/DBtoS3/wiki/Setting-Up-PostgreSQL)
* [MySQL to S3](https://github.com/DirksCGM/DBtoS3/wiki/Setting-Up-MySQL)

## Support my work by buying me a cup of coffee!
<div align="center">
  <img src="https://raw.githubusercontent.com/DirksCGM/DBtoS3/master/static/QR%20Code.png"><br>
</div>
